@@ -32,7 +32,7 @@
 #' other variable, that is `v` when `cond_var = 1` and `u` when `cond_var = 2`.
 #'
 #' ## Discrete variables
-#' When at least one variable is discrete, mote than two columns are required
+#' When at least one variable is discrete, more than two columns are required
 #' for `u`: the first \eqn{n \times 2} block contains realizations of
 #' \eqn{F_{X_1}(x_1), F_{X_2}(x_2)}. The second \eqn{n \times 2} block contains
 #' realizations of \eqn{F_{X_1}(x_1^-), F_{X_1}(x_1^-)}. The minus indicates a
@@ -169,7 +169,7 @@ par_to_ktau <- function(family, rotation, parameters) {
 #' @export
 ktau_to_par <- function(family, tau) {
   bicop <- args2bicop(family)
-  if (!(bicop$family %in% c(family_set_elliptical, family_set_nonparametric))) {
+  if (!(bicop$family %in% family_set_rotationless)) {
     bicop$rotation <- ifelse(tau > 0, 0, 90)
   }
   bicop_tau_to_par_cpp(bicop, tau)
@@ -195,7 +195,7 @@ ktau_to_par <- function(family, tau) {
 #'
 #'
 #' ## Discrete variables
-#' When at least one variable is discrete, mote than two columns are required
+#' When at least one variable is discrete, more than two columns are required
 #' for `newdata`: the first \eqn{n \times 2} block contains realizations of
 #' \eqn{F_{X_1}(x_1), F_{X_2}(x_2)}. The second \eqn{n \times 2} block contains
 #' realizations of \eqn{F_{X_1}(x_1^-), F_{X_1}(x_1^-)}. The minus indicates a
